@@ -7,7 +7,7 @@ RDF::Trine::Parser - RDF Parser class
 
 =head1 VERSION
 
-This document describes RDF::Trine::Parser version 0.137
+This document describes RDF::Trine::Parser version 1.000
 
 =head1 SYNOPSIS
 
@@ -53,7 +53,7 @@ our %format_uris;
 our %encodings;
 
 BEGIN {
-	$VERSION	= '0.137';
+	$VERSION	= '1.000';
 	can_load( modules => {
 		'Data::UUID'	=> undef,
 		'UUID::Tiny'	=> undef,
@@ -165,6 +165,11 @@ sub new {
 Retrieves the content from C<< $url >> and attempts to parse the resulting RDF
 into C<< $model >> using a parser chosen by the associated content media type.
 
+If C<< %args >> contains a C<< 'content_cb' >> key with a CODE reference value,
+that callback function will be called after a successful response as:
+
+ $content_cb->( $url, $content, $http_response_object )
+
 =cut
 
 sub parse_url_into_model {
@@ -190,6 +195,10 @@ sub parse_url_into_model {
 	}
 	
 	my $content	= $resp->content;
+	if (my $cb = $args{content_cb}) {
+		$cb->( $url, $content, $resp );
+	}
+	
 	my $type	= $resp->header('content-type');
 	$type		=~ s/^([^\s;]+).*/$1/;
 	my $pclass	= $media_types{ $type };
@@ -204,7 +213,7 @@ sub parse_url_into_model {
 		try {
 			$parser->parse_into_model( $url, $data, $model, %args );
 			$ok	= 1;
-		}
+		} catch RDF::Trine::Error with {};
 		return 1 if ($ok);
 	} else {
 		throw RDF::Trine::Error::ParserError -text => "No parser found for content type $type";
@@ -370,8 +379,6 @@ sub parse_file {
 
 =item C<< parse ( $base_uri, $rdf, \&handler ) >>
 
-=item C<< parse_into_model ( $base_uri, $data, $model ) >>
-
 =cut
 
 
@@ -407,13 +414,18 @@ __END__
 
 =back
 
+=head1 BUGS
+
+Please report any bugs or feature requests to through the GitHub web interface
+at L<https://github.com/kasei/perlrdf/issues>.
+
 =head1 AUTHOR
 
 Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006-2010 Gregory Todd Williams. This
+Copyright (c) 2006-2012 Gregory Todd Williams. This
 program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
