@@ -7,7 +7,7 @@ RDF::Trine::Serializer - RDF Serializer class
 
 =head1 VERSION
 
-This document describes RDF::Trine::Serializer version 0.138
+This document describes RDF::Trine::Serializer version 1.000
 
 =head1 SYNOPSIS
 
@@ -34,7 +34,7 @@ our %serializer_names;
 our %format_uris;
 our %media_types;
 BEGIN {
-	$VERSION	= '0.138';
+	$VERSION	= '1.000';
 }
 
 use RDF::Trine::Serializer::NQuads;
@@ -90,12 +90,17 @@ sub new {
 =item C<< negotiate ( request_headers => $request_headers, %options ) >>
 
 Returns a two-element list containing an appropriate media type and
-RDF::Trine::Serializer object as decided by L<HTTP::Negotiate>.
-If the C<< 'request_headers' >> key-value is supplied, the
-C<< $request_headers >> is passed to C<< HTTP::Negotiate::choose >>.
-The option C<< 'restrict' >>, set to a list of serializer names, can be 
-used to limit the serializers to choose from. The rest of 
-C<< %options >> is passed through to the serializer constructor.
+RDF::Trine::Serializer object as decided by L<HTTP::Negotiate>.  If
+the C<< 'request_headers' >> key-value is supplied, the C<<
+$request_headers >> is passed to C<< HTTP::Negotiate::choose >>.  The
+option C<< 'restrict' >>, set to a list of serializer names, can be
+used to limit the serializers to choose from. Finally, an C<<'extends' >> 
+option can be set to a hashref that contains MIME-types
+as keys and a custom variant as value. This will enable the user to
+use this negotiator to return a type that isn't supported by any
+serializers. The subsequent code will have to find out how to return a
+representation. The rest of C<< %options >> is passed through to the
+serializer constructor.
 
 =cut
 
@@ -357,13 +362,18 @@ sub string {
 
 __END__
 
+=head1 BUGS
+
+Please report any bugs or feature requests to through the GitHub web interface
+at L<https://github.com/kasei/perlrdf/issues>.
+
 =head1 AUTHOR
 
 Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006-2010 Gregory Todd Williams. This
+Copyright (c) 2006-2012 Gregory Todd Williams. This
 program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
